pub enum MetaRequestType {
Default,
GetObject,
PutObject,
CopyObject,
}Expand description
What transformation to apply to a single MetaRequest to transform it into a collection of requests to S3.
Variants
Default
Send the request as-is (no transformation)
GetObject
Split the GetObject request into a series of ranged requests executed in parallel
PutObject
Split the PutObject request into multi-part uploads executed in parallel
CopyObject
Perform a multi-part copy using multiple UploadPartCopy requests executed in parallel