pub struct CredentialsProvider { /* private fields */ }Expand description
A credentials provider is an object that has an asynchronous query function for retrieving AWS credentials
Implementations
Sourceimpl CredentialsProvider
impl CredentialsProvider
Sourcepub fn new_chain_default(
allocator: &Allocator,
options: CredentialsProviderChainDefaultOptions<'_>,
) -> Result<CredentialsProvider, Error>
pub fn new_chain_default( allocator: &Allocator, options: CredentialsProviderChainDefaultOptions<'_>, ) -> Result<CredentialsProvider, Error>
Creates the default credential provider chain as used by most AWS SDKs
Sourcepub fn new_anonymous(
allocator: &Allocator,
) -> Result<CredentialsProvider, Error>
pub fn new_anonymous( allocator: &Allocator, ) -> Result<CredentialsProvider, Error>
Creates the anonymous credential provider. Anonynous credentials provider gives you anonymous credentials which can be used to skip the signing process.
Sourcepub fn new_profile(
allocator: &Allocator,
options: CredentialsProviderProfileOptions<'_>,
) -> Result<CredentialsProvider, Error>
pub fn new_profile( allocator: &Allocator, options: CredentialsProviderProfileOptions<'_>, ) -> Result<CredentialsProvider, Error>
Creates the profile credential provider.
Sourcepub fn new_static(
allocator: &Allocator,
options: CredentialsProviderStaticOptions<'_>,
) -> Result<CredentialsProvider, Error>
pub fn new_static( allocator: &Allocator, options: CredentialsProviderStaticOptions<'_>, ) -> Result<CredentialsProvider, Error>
Creates a static credential provider that always returns the given credentials