EventLoopGroup

Struct EventLoopGroup 

pub struct EventLoopGroup { /* private fields */ }
An event loop group collects one or more EventLoops together for processor affiniity and load balancing purposes

Implementations

Source

impl EventLoopGroup

pub fn new_default( allocator: &Allocator, max_threads: Option<u16>, on_shutdown: impl FnOnce() + Send + 'static, ) -> Result<EventLoopGroup, Error>

Create a new default EventLoopGroup. max_threads: use None for the CRT default on_shutdown will be called when the event loop group shuts down.

pub fn get_next_loop(&self) -> Result<EventLoop, Error>

Get the next event loop to schedule a task on. (Internally, the CRT will make a choice on which loop in the group will be returned.)

pub fn get_loop_count(&self) -> usize

Get the number of loops in this group.