Struct mountpoint_s3_client::config::S3ClientConfig
source · pub struct S3ClientConfig { /* private fields */ }Expand description
Configurations for the CRT-based S3 client
Implementations
sourceimpl S3ClientConfig
impl S3ClientConfig
pub fn new() -> Self
sourcepub fn auth_config(self, auth_config: S3ClientAuthConfig) -> Self
pub fn auth_config(self, auth_config: S3ClientAuthConfig) -> Self
Set the configuration for authenticating to S3
sourcepub fn part_size(self, part_size: usize) -> Self
pub fn part_size(self, part_size: usize) -> Self
Set the part size for multi-part operations to S3 (both PUT and GET)
sourcepub fn throughput_target_gbps(self, throughput_target_gbps: f64) -> Self
pub fn throughput_target_gbps(self, throughput_target_gbps: f64) -> Self
Set the target throughput in Gbps for the S3 client
sourcepub fn endpoint_config(self, endpoint_config: EndpointConfig) -> Self
pub fn endpoint_config(self, endpoint_config: EndpointConfig) -> Self
Set the endpoint configuration for endpoint resolution
sourcepub fn user_agent(self, user_agent: UserAgent) -> Self
pub fn user_agent(self, user_agent: UserAgent) -> Self
Set a constructor for the HTTP User-agent header for S3 requests
sourcepub fn request_payer(self, request_payer: &str) -> Self
pub fn request_payer(self, request_payer: &str) -> Self
Set a value for the request payer HTTP header for S3 requests
sourcepub fn bucket_owner(self, bucket_owner: &str) -> Self
pub fn bucket_owner(self, bucket_owner: &str) -> Self
Set an expected bucket owner value
sourcepub fn max_attempts(self, max_attempts: NonZeroUsize) -> Self
pub fn max_attempts(self, max_attempts: NonZeroUsize) -> Self
Set a maximum number of attempts for S3 requests. Will be overridden by the
AWS_MAX_ATTEMPTS environment variable if set.
sourcepub fn read_backpressure(self, read_backpressure: bool) -> Self
pub fn read_backpressure(self, read_backpressure: bool) -> Self
Set the flag for backpressure read
sourcepub fn initial_read_window(self, initial_read_window: usize) -> Self
pub fn initial_read_window(self, initial_read_window: usize) -> Self
Set a value for initial backpressure read window size