pub enum ObjectClientError<S, C> {
ServiceError(S),
ClientError(C),
}
Errors returned by calls to an ObjectClient. Errors that are explicitly modeled on a
per-request-type basis are [ServiceError]s. Other generic or unhandled errors are
[ClientError]s.
The distinction between these two types of error can sometimes be blurry. As a rough heuristic,
[ServiceError]s are those that any reasonable implementation of an object client would be
capable of experiencing, and [ClientError]s are anything else. For example, any object client
could experience a “no such key” error, but only object clients that implement a permissions
system could experience “permission denied” errors. When in doubt, we err towards not adding
new [ServiceError]s, as they are public API for every object client.
An error returned by the service itself
An error within the object client (for example, an unexpected response, or a failure to
construct the request).
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read more
The lower-level source of this error, if any.
Read more
👎Deprecated since 1.42.0: use the Display impl or to_string()
👎Deprecated since 1.33.0: replaced by Error::source, which can support downcasting
🔬This is a nightly-only experimental API. (error_generic_member_access)
Provides type based access to context intended for error reports.
Read more
Converts to this type from the input type.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Converts to this type from the input type.
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
🔬This is a nightly-only experimental API. (provide_any)
Data providers should implement this method to provide
all values they are able to
provide by using
demand.
Read more
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.