pub struct InstanceInfo { /* private fields */ }Expand description
Information on the EC2 instance from the IMDS client. The client is queried lazily and only if
the AWS_EC2_METADATA_DISABLED environment variable is not set.
Implementations
Sourceimpl InstanceInfo
impl InstanceInfo
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new instance. The IMDS client will only be queried when a method on the instance is
called, and only if the AWS_EC2_METADATA_DISABLED environment variable is not set.
Sourcepub fn region(&self) -> Result<&str, &InstanceInfoError>
pub fn region(&self) -> Result<&str, &InstanceInfoError>
The region for the current instance, if it can be retrieved using the IMDS client.
Sourcepub fn instance_type(&self) -> Result<&str, &InstanceInfoError>
pub fn instance_type(&self) -> Result<&str, &InstanceInfoError>
The instance type for the current instance, if it can be retrieved using the IMDS client.