pub struct MockClient { /* private fields */ }
A mock implementation of an object client that we can manually add objects to, and then query via the ObjectClient APIs.

Implementations

source

impl MockClient

source

pub fn new(config: MockClientConfig) -> Self

Create a new MockClient with the given config

source

pub fn add_object(&self, key: &str, value: MockObject)

Add an object to this mock client’s bucket

source

pub fn remove_object(&self, key: &str)

Remove object for the mock client’s bucket

source

pub fn contains_key(&self, key: &str) -> bool

Returns true if this mock client’s bucket contains the specified key

source

pub fn contains_prefix(&self, prefix: &str) -> bool

Returns true if this mock client’s bucket contains the specified common prefix