Struct mountpoint_s3_client::DeleteObjectResult
source · #[non_exhaustive]pub struct DeleteObjectResult {}Expand description
Result of a ObjectClient::delete_object request
Note: DeleteObject calls on a non-existent object within a bucket are considered a success.
TODO: Populate this struct with return fields from the S3 API, e.g., version id, delete marker.