Struct mountpoint_s3_client::ListObjectsResult
source · #[non_exhaustive]pub struct ListObjectsResult {
pub bucket: String,
pub objects: Vec<ObjectInfo>,
pub common_prefixes: Vec<String>,
pub next_continuation_token: Option<String>,
}Expand description
Result of a ObjectClient::list_objects request
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: StringThe name of the bucket.
objects: Vec<ObjectInfo>The list of objects.
common_prefixes: Vec<String>The list of common prefixes. This rolls up all of the objects with a common prefix up to the next instance of the delimiter.
next_continuation_token: Option<String>If present, the continuation token to use to query more results.