pub enum ObjectAttribute {
ETag,
Checksum,
ObjectParts,
StorageClass,
ObjectSize,
}Expand description
All possible object attributes that can be retrived from ObjectClient::get_object_attributes. Fields that you do not specify are not returned.
Variants
ETag
ETag of the object
Checksum
Checksum of the object
ObjectParts
Object parts metadata for multi part object
StorageClass
Storage class of the object
ObjectSize
Object size