Enum PutObjectTrailingChecksums

pub enum PutObjectTrailingChecksums {
    Enabled,
    ReviewOnly,
    Disabled,
}
How CRC32c checksums are used for parts of a multi-part PutObject request

Variants



Enabled

Checksums are computed, passed to upload review, and also sent to S3



ReviewOnly

Checksums are computed, passed to upload review, but not sent to S3



Disabled

Checksums are not computed on the client side