Enum mountpoint_s3_client::types::RestoreStatus
source · pub enum RestoreStatus {
InProgress,
Restored {
expiry: SystemTime,
},
}Expand description
Restoration status for S3 objects in flexible retrieval storage classes.
See Checking restore status and expiration date in the Amazon S3 User Guide for more details.
Variants
InProgress
S3 returns this status after it accepted a restoration request, but not have completed it yet. Objects with this status are not readable.
Restored
This status means that restoration is fully completed. Note that restored objects are stored only for the number of days that was specified in the request.
Fields

expiry: SystemTimeTrait Implementations
sourceimpl Clone for RestoreStatus
impl Clone for RestoreStatus
sourcefn clone(&self) -> RestoreStatus
fn clone(&self) -> RestoreStatus
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RestoreStatus
impl Debug for RestoreStatus
impl Copy for RestoreStatus