pub struct GetObjectAttributesParts {
pub is_truncated: Option<bool>,
pub max_parts: Option<usize>,
pub next_part_number_marker: Option<usize>,
pub part_number_marker: Option<usize>,
pub parts: Option<Vec<ObjectPart>>,
pub total_parts_count: Option<usize>,
}Expand description
Metadata about object parts from GetObjectAttributes API.
See GetObjectAttributesParts in the Amazon S3 API Reference for more details.
Fields
is_truncated: Option<bool>Indicates whether the returned list of parts is truncated
max_parts: Option<usize>Maximum number of parts allowed in the response
next_part_number_marker: Option<usize>When a list is truncated, this element specifies the next marker
part_number_marker: Option<usize>The marker for the current part
parts: Option<Vec<ObjectPart>>Array of metadata for particular parts
total_parts_count: Option<usize>Total number of parts