GetObjectParams

Struct GetObjectParams 

#[non_exhaustive]
pub struct GetObjectParams { pub range: Option<Range<u64>>, pub if_match: Option<ETag>, pub checksum_mode: Option<ChecksumMode>, pub custom_id: Option<u64>, }
Parameters to a get_object request

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
range: Option<Range<u64>>if_match: Option<ETag>checksum_mode: Option<ChecksumMode>custom_id: Option<u64>

An optional caller-supplied identifier passed through to the memory pool on buffer allocations for this request. Not related to the S3 request ID returned by the service.

Implementations

Source

impl GetObjectParams

pub fn new() -> Self

Create a default GetObjectParams.

pub fn range(self, value: Option<Range<u64>>) -> Self

Set the range retrieved by the GetObject request

pub fn if_match(self, value: Option<ETag>) -> Self

Set the required etag on the object

pub fn checksum_mode(self, value: Option<ChecksumMode>) -> Self

Set option to retrieve checksum as part of the GetObject request

pub fn custom_id(self, value: Option<u64>) -> Self

Set an optional caller-supplied identifier passed through to the memory pool on buffer allocations for this request. Not related to the S3 request ID returned by the service.