#[non_exhaustive]pub struct HeadObjectParams {
pub checksum_mode: Option<ChecksumMode>,
}Expand description
Parameters to a head_object request
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.checksum_mode: Option<ChecksumMode>Enable to retrieve checksum as part of the HeadObject request
Implementations
Sourceimpl HeadObjectParams
impl HeadObjectParams
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a default HeadObjectParams.
Sourcepub fn checksum_mode(self, value: Option<ChecksumMode>) -> Self
pub fn checksum_mode(self, value: Option<ChecksumMode>) -> Self
Set option to retrieve checksum as part of the HeadObject request