ObjectInfo

Struct ObjectInfo 

#[non_exhaustive]
pub struct ObjectInfo { pub key: String, pub size: u64, pub last_modified: OffsetDateTime, pub storage_class: Option<String>, pub restore_status: Option<RestoreStatus>, pub etag: String, pub checksum_algorithms: Vec<ChecksumAlgorithm>, }
Metadata about a single S3 object.

See Object in the Amazon S3 API Reference for more details.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
key: String

Key for this object.

size: u64

Size of this object in bytes.

last_modified: OffsetDateTime

The time this object was last modified.

storage_class: Option<String>

Storage class for this object. Optional because head_object does not return the storage class in its response for Standard objects. See examples in the Amazon S3 API Reference

restore_status: Option<RestoreStatus>

Objects in flexible retrieval storage classes (such as GLACIER and DEEP_ARCHIVE) are only accessible after restoration

etag: String

Entity tag of this object.

checksum_algorithms: Vec<ChecksumAlgorithm>

The algorithm that was used to create a checksum of the object.

The Amazon S3 API Reference specifies this field as a list of strings, so we return here a Vec of ChecksumAlgorithm.