#[non_exhaustive]pub struct PutObjectParams {
pub trailing_checksums: PutObjectTrailingChecksums,
pub storage_class: Option<String>,
pub server_side_encryption: Option<String>,
pub ssekms_key_id: Option<String>,
pub custom_headers: Vec<(String, String)>,
pub object_metadata: HashMap<String, String>,
}Expand description
Parameters to a put_object request
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trailing_checksums: PutObjectTrailingChecksumsEnable Crc32c trailing checksums.
storage_class: Option<String>Storage class to be used when creating new S3 object
server_side_encryption: Option<String>The server-side encryption algorithm to be used for this object in Amazon S3 (for example, AES256, aws:kms, aws:kms:dsse)
ssekms_key_id: Option<String>If server_side_encryption has a valid value of aws:kms or aws:kms:dsse, this value may be used to specify AWS KMS key ID to be used
when creating new S3 object
custom_headers: Vec<(String, String)>Custom headers to add to the request
object_metadata: HashMap<String, String>User-defined object metadata
Implementations
Sourceimpl PutObjectParams
impl PutObjectParams
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a default PutObjectParams.
Sourcepub fn trailing_checksums(self, value: PutObjectTrailingChecksums) -> Self
pub fn trailing_checksums(self, value: PutObjectTrailingChecksums) -> Self
Set Crc32c trailing checksums.
Sourcepub fn storage_class(self, value: String) -> Self
pub fn storage_class(self, value: String) -> Self
Set the storage class.
Sourcepub fn server_side_encryption(self, value: Option<String>) -> Self
pub fn server_side_encryption(self, value: Option<String>) -> Self
Set server-side encryption type.
Sourcepub fn ssekms_key_id(self, value: Option<String>) -> Self
pub fn ssekms_key_id(self, value: Option<String>) -> Self
Set KMS key ID to be used for server-side encryption.
Sourcepub fn add_custom_header(self, name: String, value: String) -> Self
pub fn add_custom_header(self, name: String, value: String) -> Self
Add a custom header to the request.
Sourcepub fn object_metadata(self, value: HashMap<String, String>) -> Self
pub fn object_metadata(self, value: HashMap<String, String>) -> Self
Set user defined object metadata.