Struct mountpoint_s3_client::types::PutObjectResult
source · #[non_exhaustive]pub struct PutObjectResult {
pub sse_type: Option<String>,
pub sse_kms_key_id: Option<String>,
}Expand description
Result of a ObjectClient::put_object request
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sse_type: Option<String>Server-side encryption type that was used to store new object (reported by S3)
sse_kms_key_id: Option<String>Server-side encryption KMS key ID that was used to store new object (reported by S3)