PutObjectSingleParams

Struct PutObjectSingleParams 

#[non_exhaustive]
pub struct PutObjectSingleParams { pub checksum: Option<UploadChecksum>, pub storage_class: Option<String>, pub server_side_encryption: Option<String>, pub ssekms_key_id: Option<String>, pub if_match: Option<ETag>, pub write_offset_bytes: Option<u64>, pub custom_headers: Vec<(String, String)>, pub object_metadata: HashMap<String, String>, }
Parameters to a put_object_single request

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
checksum: Option<UploadChecksum>

User-provided checksum of the data to upload.

storage_class: Option<String>

Storage class to be used when creating new S3 object

server_side_encryption: Option<String>

The server-side encryption algorithm to be used for this object in Amazon S3 (for example, AES256, aws:kms, aws:kms:dsse)

ssekms_key_id: Option<String>

If server_side_encryption has a valid value of aws:kms or aws:kms:dsse, this value may be used to specify AWS KMS key ID to be used when creating new S3 object

if_match: Option<ETag>

Requires pre-existing object to match the given etag in order to perform the request

write_offset_bytes: Option<u64>

Offset on the pre-existing object where to append the data in the request

custom_headers: Vec<(String, String)>

Custom headers to add to the request

object_metadata: HashMap<String, String>

User-defined object metadata

Implementations

Source

impl PutObjectSingleParams

pub fn new() -> Self

Create a default PutObjectSingleParams.

pub fn new_for_append(offset: u64) -> Self

Create a PutObjectSingleParams for an append request at the given offset.

pub fn checksum(self, value: Option<UploadChecksum>) -> Self

Set checksum.

pub fn storage_class(self, value: String) -> Self

Set the storage class.

pub fn server_side_encryption(self, value: Option<String>) -> Self

Set server-side encryption type.

pub fn ssekms_key_id(self, value: Option<String>) -> Self

Set KMS key ID to be used for server-side encryption.

pub fn if_match(self, value: Option<ETag>) -> Self

Set the required etag on the pre-existing object.

pub fn write_offset_bytes(self, value: u64) -> Self

Set the offset on the pre-existing object where to append the data in the request.

pub fn add_custom_header(self, name: String, value: String) -> Self

Add a custom header to the request.

pub fn object_metadata(self, value: HashMap<String, String>) -> Self

Set user defined object metadata.