Type Alias ChecksumAlgorithm

pub type ChecksumAlgorithm = ChecksumAlgorithm;
A checksum algorithm used by the object client for integrity checks on uploads and downloads.

Aliased Type

enum ChecksumAlgorithm {
    Crc64nvme,
    Crc32c,
    Crc32,
    Sha1,
    Sha256,
    Unknown(String),
}

Variants



Crc64nvme

Crc64nvme checksum.



Crc32c

Crc32c checksum.



Crc32

Crc32 checksum.



Sha1

Sha1 checksum.



Sha256

Sha256 checksum.



Unknown(String)

Checksum of a type unknown to this S3 client.

This type will be used if Mountpoint ever encounters a checksum algorithm it doesn’t recognize. This should allow Mountpoint to continue with most file operations which don’t depend on the checksum algorithm.