pub type GetBodyPart = (u64, Box<[u8]>);Expand description
A single element of a get_object response stream is a pair of
offset within the object and the bytes starting at that offset.
pub type GetBodyPart = (u64, Box<[u8]>);A single element of a get_object response stream is a pair of
offset within the object and the bytes starting at that offset.