pub type ObjectClientResult<T, S, C> = Result<T, ObjectClientError<S, C>>;Expand description
Shorthand type for the result of an object client request
Aliased Type
enum ObjectClientResult<T, S, C> {
Ok(T),
Err(ObjectClientError<S, C>),
}pub type ObjectClientResult<T, S, C> = Result<T, ObjectClientError<S, C>>;Shorthand type for the result of an object client request
enum ObjectClientResult<T, S, C> {
Ok(T),
Err(ObjectClientError<S, C>),
}