#[non_exhaustive]pub struct RustLogAdapter;Expand description
This is an implementation of LoggerImpl that can be used to pipe CRT log messages into the
Rust log facade. To install it, call RustLogAdapter::try_init(), and then CRT log messages
will be sent to the log facade. These messages will follow that facade’s logic for when to
emit log messages. All CRT log messages will have a target that starts with the value of
AWSCRT_LOG_TARGET.
Implementations
Sourceimpl RustLogAdapter
impl RustLogAdapter
Sourcepub fn try_init() -> Result<(), LoggerInitError>
pub fn try_init() -> Result<(), LoggerInitError>
Try to install the log adapter as the current CRT logger. Only one CRT logger can be
installed for the lifetime of the program, so this returns Err if a logger has already been
installed.