pub enum S3RequestError {
InternalError(Box<dyn Error + Send + Sync>),
CrtError(Error),
ConstructionFailure(ConstructionError),
ResponseError(MetaRequestResult),
IncorrectRegion(String, ClientErrorMetadata),
Forbidden(String, ClientErrorMetadata),
NoSigningCredentials,
RequestCanceled,
Throttled,
EmptyReadWindow,
}Expand description
Errors returned by the CRT-based S3 client
Variants
InternalError(Box<dyn Error + Send + Sync>)
An internal error from within the S3 client. The request may have been sent.
CrtError(Error)
An internal error from within the AWS Common Runtime. The request may have been sent.
ConstructionFailure(ConstructionError)
An error during construction of a request. The request was not sent.
ResponseError(MetaRequestResult)
The request was sent but an unknown or unhandled failure occurred while processing it.
IncorrectRegion(String, ClientErrorMetadata)
The request was made to the wrong region
Forbidden(String, ClientErrorMetadata)
Forbidden
NoSigningCredentials
The request was attempted but could not be signed due to no available credentials
RequestCanceled
The request was canceled
Throttled
The request was throttled by S3
EmptyReadWindow
Cannot fetch more data because current read window is exhausted. The read window must be advanced using [GetObjectRequest::increment_read_window(u64)] to continue fetching new data.