Struct mountpoint_s3_client::mock_client::MockClient
source · pub struct MockClient { /* private fields */ }Expand description
A mock implementation of an object client that we can manually add objects to, and then query via the ObjectClient APIs.
Implementations
sourceimpl MockClient
impl MockClient
sourcepub fn new(config: MockClientConfig) -> Self
pub fn new(config: MockClientConfig) -> Self
Create a new MockClient with the given config
sourcepub fn add_object(&self, key: &str, value: MockObject)
pub fn add_object(&self, key: &str, value: MockObject)
Add an object to this mock client’s bucket
sourcepub fn remove_object(&self, key: &str)
pub fn remove_object(&self, key: &str)
Remove object for the mock client’s bucket
sourcepub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Returns true if this mock client’s bucket contains the specified key
sourcepub fn contains_prefix(&self, prefix: &str) -> bool
pub fn contains_prefix(&self, prefix: &str) -> bool
Returns true if this mock client’s bucket contains the specified common prefix