Type Definition mountpoint_s3_client::GetBodyPart
source · pub type GetBodyPart = (u64, Box<[u8]>);Expand description
A single element of the ObjectClient::get_object response is a pair of offset within the object and the bytes starting at that offset.