pub enum RestoreStatus {
    InProgress,
    Restored {
        expiry: SystemTime,
    },
}
Restoration status for S3 objects in flexible retrieval storage classes.

See Checking restore status and expiration date in the Amazon S3 User Guide for more details.

Variants



InProgress

S3 returns this status after it accepted a restoration request, but not have completed it yet. Objects with this status are not readable.



Restored

Fields

expiry: SystemTime

This status means that restoration is fully completed. Note that restored objects are stored only for the number of days that was specified in the request.