#[non_exhaustive]pub struct HeadObjectResult {
pub size: u64,
pub last_modified: OffsetDateTime,
pub etag: ETag,
pub storage_class: Option<String>,
pub restore_status: Option<RestoreStatus>,
pub checksum: Checksum,
pub sse_type: Option<String>,
pub sse_kms_key_id: Option<String>,
}Expand description
Result of a head_object request
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.size: u64Size of the object in bytes.
Refers to the Content-Length HTTP header for HeadObject.
last_modified: OffsetDateTimeThe time this object was last modified.
etag: ETagEntity tag of this object.
storage_class: Option<String>Storage class for this object.
The value is optional because HeadObject does not return the storage class in its response for objects in the S3 Standard storage class. See examples in the Amazon S3 API Reference.
restore_status: Option<RestoreStatus>Objects in flexible retrieval storage classes (such as GLACIER and DEEP_ARCHIVE) are only accessible after restoration
checksum: ChecksumChecksum of the object.
HeadObject must explicitly request for this field to be included, otherwise the values will be empty.
sse_type: Option<String>Server-side encryption type that was used to store the object.
sse_kms_key_id: Option<String>Server-side encryption KMS key ID that was used to store the object.