Struct mountpoint_s3_client::types::PutObjectParams

source ·
#[non_exhaustive]
pub struct PutObjectParams { pub trailing_checksums: PutObjectTrailingChecksums, pub storage_class: Option<String>, pub server_side_encryption: Option<String>, pub ssekms_key_id: Option<String>, }
Parameters to a put_object request

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
trailing_checksums: PutObjectTrailingChecksums

Enable Crc32c trailing checksums.

storage_class: Option<String>

Storage class to be used when creating new S3 object

server_side_encryption: Option<String>

The server-side encryption algorithm to be used for this object in Amazon S3 (for example, AES256, aws:kms, aws:kms:dsse)

ssekms_key_id: Option<String>

If server_side_encryption has a valid value of aws:kms or aws:kms:dsse, this value may be used to specify AWS KMS key ID to be used when creating new S3 object

Implementations

source

impl PutObjectParams

source

pub fn new() -> Self

Create a default PutObjectParams.

source

pub fn trailing_checksums(self, value: PutObjectTrailingChecksums) -> Self

Set Crc32c trailing checksums.

source

pub fn storage_class(self, value: String) -> Self

Set the storage class.

source

pub fn server_side_encryption(self, value: Option<String>) -> Self

Set server-side encryption type.

source

pub fn ssekms_key_id(self, value: Option<String>) -> Self

Set KMS key ID to be used for server-side encryption.