#[non_exhaustive]pub struct PutObjectSingleParams {
pub checksum: Option<UploadChecksum>,
pub storage_class: Option<String>,
pub server_side_encryption: Option<String>,
pub ssekms_key_id: Option<String>,
pub if_match: Option<ETag>,
pub write_offset_bytes: Option<u64>,
pub custom_headers: Vec<(String, String)>,
pub object_metadata: HashMap<String, String>,
}Expand description
Parameters to a put_object_single request
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.checksum: Option<UploadChecksum>User-provided checksum of the data to upload.
storage_class: Option<String>Storage class to be used when creating new S3 object
server_side_encryption: Option<String>The server-side encryption algorithm to be used for this object in Amazon S3 (for example, AES256, aws:kms, aws:kms:dsse)
ssekms_key_id: Option<String>If server_side_encryption has a valid value of aws:kms or aws:kms:dsse, this value may be used to specify AWS KMS key ID to be used
when creating new S3 object
if_match: Option<ETag>Requires pre-existing object to match the given etag in order to perform the request
write_offset_bytes: Option<u64>Offset on the pre-existing object where to append the data in the request
custom_headers: Vec<(String, String)>Custom headers to add to the request
object_metadata: HashMap<String, String>User-defined object metadata
Implementations
Sourceimpl PutObjectSingleParams
impl PutObjectSingleParams
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a default PutObjectSingleParams.
Sourcepub fn new_for_append(offset: u64) -> Self
pub fn new_for_append(offset: u64) -> Self
Create a PutObjectSingleParams for an append request at the given offset.
Sourcepub fn checksum(self, value: Option<UploadChecksum>) -> Self
pub fn checksum(self, value: Option<UploadChecksum>) -> Self
Set checksum.
Sourcepub fn storage_class(self, value: String) -> Self
pub fn storage_class(self, value: String) -> Self
Set the storage class.
Sourcepub fn server_side_encryption(self, value: Option<String>) -> Self
pub fn server_side_encryption(self, value: Option<String>) -> Self
Set server-side encryption type.
Sourcepub fn ssekms_key_id(self, value: Option<String>) -> Self
pub fn ssekms_key_id(self, value: Option<String>) -> Self
Set KMS key ID to be used for server-side encryption.
Sourcepub fn if_match(self, value: Option<ETag>) -> Self
pub fn if_match(self, value: Option<ETag>) -> Self
Set the required etag on the pre-existing object.
Sourcepub fn write_offset_bytes(self, value: u64) -> Self
pub fn write_offset_bytes(self, value: u64) -> Self
Set the offset on the pre-existing object where to append the data in the request.
Sourcepub fn add_custom_header(self, name: String, value: String) -> Self
pub fn add_custom_header(self, name: String, value: String) -> Self
Add a custom header to the request.
Sourcepub fn object_metadata(self, value: HashMap<String, String>) -> Self
pub fn object_metadata(self, value: HashMap<String, String>) -> Self
Set user defined object metadata.